package
Version:
v0.0.0-...-51cf6c1
Opens a new window with list of versions in this module.
Published: Apr 17, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CreateOrderModel struct {
ProductName string `json:"ProductName" binding:"required"`
Coupon string `json:"Coupon"`
}
type GetUserInfoModelInput struct {
User string `uri:"user" binding:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.